Learn R Programming

covid19br (version 1.0.0.1)

add_epi_rates: Adding incidence, mortality and lethality rates to the downloaded data

Description

This function adds the incidence, mortality and lethality rates to a given data set downloaded by the covid19br::downloadCovid19() function.

Usage

add_epi_rates(data, ...)

Value

the data set with the added incidence, mortality and lethality rates.

Arguments

data

a data set downloaded using the covid19br::downloadCovid19() function.

...

further arguments passed to other methods.

Author

Fabio N. Demarqui fndemarqui@est.ufmg.br

Details

The function add_epi_rates() was designed to work with the original names of the variables accumDeaths, accummCases and pop available in the data set downloaded by the covid19br::downloadCovid19(). For this reason, this function must be used before any change in such variable names.

Examples

Run this code
# \donttest{
library(covid19br)
library(dplyr)

brazil <- downloadCovid19(level = "brazil")
brazil <- add_epi_rates(brazil)
glimpse(brazil)
# }

Run the code above in your browser using DataLab